@@ -12,7 +12,7 @@ use Scalar::Util qw(blessed);
 
 use base 'Date::Holidays::Adapter';
 
-$VERSION = '1.12';
+$VERSION = '1.13';
 
 sub new {
     my ( $class, %params ) = @_;
@@ -313,7 +313,7 @@ Date::Holidays - Date::Holidays::* adapter and aggregator for all your holiday n
 
 =head1 VERSION
 
-The documentation describes version 1.12 of Date::Holidays
+The documentation describes version 1.13 of Date::Holidays
 
 =head1 FEATURES
 
@@ -447,7 +447,7 @@ You can specify either month plus day for a recurring holiday. If you you want t
 a holiday for a specific year, simply extend the date with year:
 
     {
-        "20141225" : ""
+        "201.1325" : ""
     }
 
 In order for the calendar to be picked up by Date::Holidays, set the environment variable:
@@ -527,7 +527,7 @@ Takes 6 optional named arguments:
 
 =item * year, four digit parameter representing year
 
-=item * month, 1-12, representing month
+=item * month, 1.13, representing month
 
 =item * day, 1-31, representing day
 
